---
title: Chef Habitat 0.56.0 Released
date: 2018-05-29
author: Christopher Maier
tags: release notes
category: product
classes: body-article
---

We are happy to announce the release of Chef Habitat 0.56.0. We have a number of new features as well as bug fixes, so please read on for all the details. If you just want the binaries, head on over to [Install Chef Habitat](https://www.habitat.sh/docs/using-habitat/#install-habitat). Thanks again for using Chef Habitat!

## Highlights:

- Remote command-and-control of the Supervisor
- "Relaxed" binding mode
- JSON logging output
- Additional configuration environment variables for the Chef Habitat CLI
- Fix `hab origin key upload` arguments
- Bind validation
- Various templating improvements
- Improvements to `hab bldr job status`

### Remote Command-and-Control of the Supervisor
The largest change in this release is a reworking of the interaction protocol between the `hab` CLI and the Supervisor. Previously, this was accomplished mainly by communicating through the filesystem, which ultimately limits the things that we can make the Supervisor do. Now, `hab` communicates with the Supervisor via a defined TCP protocol, which lays the foundation for a number of exciting capabilities we’ll be rolling out in the coming months. A new capability that is immediately available, though, is the ability to communicate remotely with your Supervisors!

There will be some actions that users will need to take to properly use the new Supervisor; for details, please read [our blog post on the topic](https://www.habitat.sh/blog/2018/05/changes-in-the-0.56.0-supervisor/).

## "Relaxed" binding mode
If your service can tolerate starting in the absence of its binds being satisfied, you can now start it with `--binding-mode=relaxed`. When your binds become satisfied, your application can reconfigure itself to take this into account. The default behavior is to still block service startup until all binds are satisfied; this can be explicitly requested with `--binding-mode=strict`. Note however that before Chef Habitat reaches version 1.0, the default will change to `--binding-mode=relaxed`, so please plan accordingly.

* https://github.com/habitat-sh/habitat/pull/5024

### JSON Logging Output
The Supervisor can now output JSON-formatted logs! Just add `--json-logging` when you start the Supervisor.

* [https://github.com/habitat-sh/habitat/pull/5033](https://github.com/habitat-sh/habitat/pull/5033)

### Additional configuration environment variables
New environment variables are now available:
`HAB_CLIENT_SOCKET_TIMEOUT` - this allows configuration of socket timeout for the Chef Habitat client.  The default is 120 seconds. It can be useful when dealing with uploads of large hart files.
`HAB_SSL_CERT_VERIFY_NONE` - if this is set, the Chef Habitat client will not attempt to verify the SSL certificate when connecting to a depot. This can be useful if authenticating against an on-premise hosted Builder depot, which is configured with a self-signed SSL certificate, or for testing purposes.

* [https://github.com/habitat-sh/core/pull/31](https://github.com/habitat-sh/core/pull/31)
* [https://github.com/habitat-sh/core/pull/29](https://github.com/habitat-sh/core/pull/29)

### Fix hab origin key upload arguments
The `hab origin key upload` command was not able to execute correctly since it required two arguments that were mutually exclusive.  This has been fixed by making the arguments optional.

* [https://github.com/habitat-sh/habitat/pull/5013](https://github.com/habitat-sh/habitat/pull/5013)

### Bind Validation
As part of the relaxed binding mode work, we now are able to validate binding contracts at runtime. This means that if the service group you bind does not satisfy the expected contract, we will log this, and (more importantly), not register the bind as being satisfied. This is rechecked as the service runs, as well.

## Various Templating Improvements
After some internal reworking, we have several important improvements to our templating data, all of which should result in templates that are more clear and easier to reason about.

First, the `members` list of a service group now only contains live and suspect members; you no longer need to use the `eachAlive` helper to filter out dead and departed members.

Next, the leader of a service group can now be accessed directly using the `leader` key. Previously, it was available under the `first` key, but only if the group was running under a leader topology (it was just a regular member otherwise). If the group has no leader, then this key will be `null`, allowing you to use it in boolean checks to streamline your templates.

Third, when a binding group has no live or suspect members, it will be removed from the templating data. This allows your service to easily respond when it has binds that go away while it is running.

Finally, as a result of the internal refactoring, we now are able to define the template rendering data using JSON Schema. Additionally, the documentation on the website is automatically generated from this same schema.

* [https://github.com/habitat-sh/habitat/pull/4823](https://github.com/habitat-sh/habitat/pull/4823)
* [https://github.com/habitat-sh/habitat/pull/4836](https://github.com/habitat-sh/habitat/pull/4836)
* [https://github.com/habitat-sh/habitat/pull/4914](https://github.com/habitat-sh/habitat/pull/4914)
* [https://www.habitat.sh/docs/reference/#template-data](https://www.habitat.sh/docs/reference/#template-data)

### Improvements to `hab bldr job status`
There are a number of key improvements to the `hab bldr job status` command. In addition to being much faster to execute when fetching status for an origin, it also has improvements in the output rendering, and additional options for formating.

* [https://github.com/habitat-sh/habitat/pull/4841](https://github.com/habitat-sh/habitat/pull/4841)

### Chef Habitat Launcher: New Version Released, Please Update
This release of Chef Habitat includes a new release of the Launcher, a small binary that the Supervisor uses to help manage its supervised processes. Whereas the Supervisor is able to automatically update itself, the Launcher is currently released a bit differently, by design; it should be rare that the Launcher ever needs to change. To update your Launchers, you will need to run `hab pkg install core/hab-launcher` on each machine that has a Supervisor, and then restart your Supervisor. This will, by necessity, require a restart of supervised services, so factor that into your planning.

## Chef Habitat Changelog

### [0.56.0](https://github.com/habitat-sh/habitat/tree/0.56.0) (05-10-2018)
[Full Changelog](https://github.com/habitat-sh/habitat/compare/0.55.0...0.56.0)

### Features & Enhancements

- Splunk Blog Post [\#5022](https://github.com/habitat-sh/habitat/issues/5022)
- Capture the commit SHA responsible for/associated with a build [\#5009](https://github.com/habitat-sh/habitat/issues/5009)
- Update the logo in sample-node-app [\#4972](https://github.com/habitat-sh/habitat/issues/4972)
- README diagrams link broken [\#4968](https://github.com/habitat-sh/habitat/issues/4968)
- \[www\] Deprecated "View on GitHub" button hanging on laptop-size screens [\#4954](https://github.com/habitat-sh/habitat/issues/4954)
- Generate Builder API documentation [\#4943](https://github.com/habitat-sh/habitat/issues/4943)
- Replace Chef Habitat logo on Chef-managed web properties  [\#4941](https://github.com/habitat-sh/habitat/issues/4941)
- Launcher build and release process needs documentation [\#4940](https://github.com/habitat-sh/habitat/issues/4940)
- Update logos in embedded screenshots in demos & tutorials  [\#4937](https://github.com/habitat-sh/habitat/issues/4937)
- More logo cleanup [\#4930](https://github.com/habitat-sh/habitat/issues/4930)
- Replace the Builder favicon [\#4903](https://github.com/habitat-sh/habitat/issues/4903)
- Replace the website favicon [\#4902](https://github.com/habitat-sh/habitat/issues/4902)
- Replace the Chef Habitat logo in Builder [\#4882](https://github.com/habitat-sh/habitat/issues/4882)
- Suppress related videos on the home page demo [\#4868](https://github.com/habitat-sh/habitat/issues/4868)
- Update the infographics URLs [\#4857](https://github.com/habitat-sh/habitat/issues/4857)
- Document origin secrets [\#4849](https://github.com/habitat-sh/habitat/issues/4849)
- Docs home page improvement [\#4848](https://github.com/habitat-sh/habitat/issues/4848)
- starting a service with a  in the user directory user.toml is not documented [\#4842](https://github.com/habitat-sh/habitat/issues/4842)
- Automatically generate template render context documentation [\#4824](https://github.com/habitat-sh/habitat/issues/4824)
- Make reference architectures more discoverable [\#4809](https://github.com/habitat-sh/habitat/issues/4809)
- UI Cleanup [\#4787](https://github.com/habitat-sh/habitat/issues/4787)
- \[documentation\] Update Docs to Reflect Dependency on Upstream Docker for Linux Users [\#4780](https://github.com/habitat-sh/habitat/issues/4780)
- Better support on-prem behavior in Builder UI [\#4770](https://github.com/habitat-sh/habitat/issues/4770)
- Formalize the contents of the template rendering context [\#4761](https://github.com/habitat-sh/habitat/issues/4761)
- Update the install docs to use Personal Access Tokens  [\#4756](https://github.com/habitat-sh/habitat/issues/4756)
- hab pkg download [\#4616](https://github.com/habitat-sh/habitat/issues/4616)
- Add a Windows based "build your own" web app tutorial [\#4529](https://github.com/habitat-sh/habitat/issues/4529)
- Better Windows coverage in reference docs [\#4499](https://github.com/habitat-sh/habitat/issues/4499)
- \[www\] Content and call-to-action doesn't match [\#4446](https://github.com/habitat-sh/habitat/issues/4446)
- Getting started guides: Node documentation [\#4400](https://github.com/habitat-sh/habitat/issues/4400)
- Create a hab command to expose various basic data about a package [\#4309](https://github.com/habitat-sh/habitat/issues/4309)
- Automatically rebuild .rs files from their .proto dependencies [\#4290](https://github.com/habitat-sh/habitat/issues/4290)
- Cannot cfize a local package [\#4205](https://github.com/habitat-sh/habitat/issues/4205)
- Add Cargo build caching to Chef Habitat Plans [\#4188](https://github.com/habitat-sh/habitat/issues/4188)
- Generate unstable studio images [\#4183](https://github.com/habitat-sh/habitat/issues/4183)
- Tar exporter: the next generation [\#4172](https://github.com/habitat-sh/habitat/issues/4172)
- RFE: In the template syntax, I want to know what topology a given service is in [\#4127](https://github.com/habitat-sh/habitat/issues/4127)
- Airgap / Offline Operational Mode [\#4039](https://github.com/habitat-sh/habitat/issues/4039)
- Update to current master of habitat-sh/core repository [\#5031](https://github.com/habitat-sh/habitat/pull/5031) ([christophermaier](https://github.com/christophermaier))
- Notify of TravisCI failures on master in HabiSlack \#notifications [\#4996](https://github.com/habitat-sh/habitat/pull/4996) ([christophermaier](https://github.com/christophermaier))
- Remove hab-pkg-tarize package [\#4995](https://github.com/habitat-sh/habitat/pull/4995) ([christophermaier](https://github.com/christophermaier))
- Update .bldr.toml paths to reflect current reality [\#4994](https://github.com/habitat-sh/habitat/pull/4994) ([christophermaier](https://github.com/christophermaier))
- Reuse recv buffer in SrvCodec [\#4967](https://github.com/habitat-sh/habitat/pull/4967) ([reset](https://github.com/reset))
- Finish remote supervisor command and control & move commands into hab binary [\#4929](https://github.com/habitat-sh/habitat/pull/4929) ([reset](https://github.com/reset))
- Expose only "active" members in RenderContext [\#4914](https://github.com/habitat-sh/habitat/pull/4914) ([christophermaier](https://github.com/christophermaier))
- \[core\] Update git repo to consume habitat-sh/core\#22. [\#4888](https://github.com/habitat-sh/habitat/pull/4888) ([fnichol](https://github.com/fnichol))
- fix pkg\_path\_for test on windows [\#4879](https://github.com/habitat-sh/habitat/pull/4879) ([mwrock](https://github.com/mwrock))
- Add notes on testing Chef Habitat package [\#4840](https://github.com/habitat-sh/habitat/pull/4840) ([baumanj](https://github.com/baumanj))
- \[studio\] Implement `run` subcommand for `stage1` Studio types. [\#4831](https://github.com/habitat-sh/habitat/pull/4831) ([fnichol](https://github.com/fnichol))
- Remote command control: Split CLI from Supervisor [\#4805](https://github.com/habitat-sh/habitat/pull/4805) ([reset](https://github.com/reset))
- \[ci\] Update `compile\_libsodium.sh` to 1.0.13. [\#4802](https://github.com/habitat-sh/habitat/pull/4802) ([fnichol](https://github.com/fnichol))
- \[common\] Add offline mode support for install logic. [\#4771](https://github.com/habitat-sh/habitat/pull/4771) ([fnichol](https://github.com/fnichol))
- Clean up hab-studio.sh linter errors and reduce duplication [\#4661](https://github.com/habitat-sh/habitat/pull/4661) ([baumanj](https://github.com/baumanj))

### Bug fixes

- Fix default configuration serialization bug [\#5110](https://github.com/habitat-sh/habitat/pull/5110)
- Fix panic when an initial service fails to load [\#5096](https://github.com/habitat-sh/habitat/pull/5096)
- Disable interface validation of config/files [\#5091](https://github.com/habitat-sh/habitat/pull/5091)
- Disable validation of config/files [\#5090](https://github.com/habitat-sh/habitat/pull/5090)
- Run the best local candidate of a service first [\#5087](https://github.com/habitat-sh/habitat/pull/5087) ([christophermaier](https://github.com/christophermaier))
- \[hab\] Fix the subcommand delegation to `hab-sup`. [\#5086](https://github.com/habitat-sh/habitat/pull/5086) ([fnichol](https://github.com/fnichol))
- \[hab\] Fix missing invocation matches for {apply,start,stop}. [\#5082](https://github.com/habitat-sh/habitat/pull/5082) ([fnichol](https://github.com/fnichol))
- \[hab\] Fix {apply, start, stop} aliases. [\#5078](https://github.com/habitat-sh/habitat/pull/5078) ([fnichol](https://github.com/fnichol))
- \[studio\] Fix building the Windows Docker image when installing pkgs. [\#5072](https://github.com/habitat-sh/habitat/pull/5072) ([fnichol](https://github.com/fnichol))
- \[plan-build.ps1]\ Use `RUNTIME_ENVIRONMENT` if necessary for run path. [\#5070](https://github.com/habitat-sh/habitat/pull/5070) ([fnichol](https://github.com/fnichol))
- Fix some command aliases [\#5064](https://github.com/habitat-sh/habitat/pull/5064) ([christophermaier](https://github.com/christophermaier))
- \[hab\] Ignore subdir entries when binlinking all programs in package. [\#5058](https://github.com/habitat-sh/habitat/pull/5058) ([fnichol](https://github.com/fnichol))
- hab origin key upload fails with --pubfile option [\#5012](https://github.com/habitat-sh/habitat/issues/5012)
- tar exporter filename ends with .gz but file is not a gzip [\#5011](https://github.com/habitat-sh/habitat/issues/5011)
- Restarting a service results in \*all\* other services being restarted [\#4898](https://github.com/habitat-sh/habitat/issues/4898)
- View on Github link \(in main nav\) wraps  [\#4883](https://github.com/habitat-sh/habitat/issues/4883)
- \[studio\] Regression: entering Studio with `HAB\_ORIGIN` unset [\#4834](https://github.com/habitat-sh/habitat/issues/4834)
- \[studio\] Regression: Plan is missing install of `hab-studio-profile.sh` [\#4832](https://github.com/habitat-sh/habitat/issues/4832)
- \\[documentation\\] Update Docs to Reflect Dependency on Upstream Docker for Linux Users [\#4780](https://github.com/habitat-sh/habitat/issues/4780)
- hab-plan-build.ps1 does not handle the assembling of custom `pkg\_version` [\#4552](https://github.com/habitat-sh/habitat/issues/4552)
- `hab pkg export docker` "stream did not contain valid UTF-8" [\#4496](https://github.com/habitat-sh/habitat/issues/4496)
- Unable to parse TOML/JSON from ENV [\#4439](https://github.com/habitat-sh/habitat/issues/4439)
- \[v0.51.0\] hab pkg binlink is not symlinking my bin [\#4390](https://github.com/habitat-sh/habitat/issues/4390)
- Binlinking of symlinks fails in Docker exporter chroot environment [\#4243](https://github.com/habitat-sh/habitat/issues/4243)
- Cannot cfize a local package [\#4205](https://github.com/habitat-sh/habitat/issues/4205)
- Generate unstable studio images [\#4183](https://github.com/habitat-sh/habitat/issues/4183)
- Properly honor the `--force` flag [\#4999](https://github.com/habitat-sh/habitat/pull/4999) ([christophermaier](https://github.com/christophermaier))
- Fix handling of environment-level configuration [\#4969](https://github.com/habitat-sh/habitat/pull/4969) ([christophermaier](https://github.com/christophermaier))
- Firmly establish role of PATH, RUNTIME\_ENVIRONMENT, & RUNTIME\_PATH metadata files [\#4962](https://github.com/habitat-sh/habitat/pull/4962) ([fnichol](https://github.com/fnichol))
- Remove exporter dependencies on Supervisor in `.bldr.toml`. [\#4916](https://github.com/habitat-sh/habitat/pull/4916) ([fnichol](https://github.com/fnichol))
- \[common\] Restore UI begin/end coloring and debugging capability. [\#4915](https://github.com/habitat-sh/habitat/pull/4915) ([fnichol](https://github.com/fnichol))
- \[plan-build-ps1\] Restore generation of package `PATH` metafile. [\#4895](https://github.com/habitat-sh/habitat/pull/4895) ([fnichol](https://github.com/fnichol))
- \[pkg-export-docker\] Only require a registry url with amazon/azure types [\#4875](https://github.com/habitat-sh/habitat/pull/4875) ([fnichol](https://github.com/fnichol))
- \[common\] Fix artifact install canonicalizing when dst doesn't exist. [\#4864](https://github.com/habitat-sh/habitat/pull/4864) ([fnichol](https://github.com/fnichol))
- prefix pkgPathFor with FS\_ROOT [\#4843](https://github.com/habitat-sh/habitat/pull/4843) ([mwrock](https://github.com/mwrock))
- \[studio\] Fix `chroot\_env` regression in \#4661. [\#4837](https://github.com/habitat-sh/habitat/pull/4837) ([fnichol](https://github.com/fnichol))
- \[studio\] Fix Plan regression in \#4661. [\#4833](https://github.com/habitat-sh/habitat/pull/4833) ([fnichol](https://github.com/fnichol))
- \[studio\] Ensure that cleanup is performed on `studio new`. [\#4830](https://github.com/habitat-sh/habitat/pull/4830) ([fnichol](https://github.com/fnichol))

### Closed issues

- hab pkg search - \[403 Forbidden\] [\#5002](https://github.com/habitat-sh/habitat/issues/5002)
- within a studio, adding a user.toml does not change configuration of a service [\#4933](https://github.com/habitat-sh/habitat/issues/4933)
- \[package\] Update for dotnet-core 2.1 [\#4931](https://github.com/habitat-sh/habitat/issues/4931)
- \[hab-sup-dev\] `hab sup load` no longer works with paths to harts [\#4919](https://github.com/habitat-sh/habitat/issues/4919)
- Logos: Packaging demo [\#4892](https://github.com/habitat-sh/habitat/issues/4892)
- Optionally bind example [\#4855](https://github.com/habitat-sh/habitat/issues/4855)
- Package binlink fails if a directory is in the parent bin directory [\#4847](https://github.com/habitat-sh/habitat/issues/4847)
- Replace the Chef Habitat logo in Builder UI [\#4845](https://github.com/habitat-sh/habitat/issues/4845)
- hab config clear ? [\#4804](https://github.com/habitat-sh/habitat/issues/4804)
- On-prem depot usage data [\#4799](https://github.com/habitat-sh/habitat/issues/4799)
- `hab pkg install -b core/openldap` fails in a clean Docker studio [\#4669](https://github.com/habitat-sh/habitat/issues/4669)

### Merged pull requests

- \[ci\] Update auth token now that GitHub tokens are fully deprecated. [\#5068](https://github.com/habitat-sh/habitat/pull/5068) ([fnichol](https://github.com/fnichol))
- Remove access token warning [\#5060](https://github.com/habitat-sh/habitat/pull/5060) ([chefsalim](https://github.com/chefsalim))
- Bump habitat\_core dependency to pick up HTTP client changes [\#5050](https://github.com/habitat-sh/habitat/pull/5050) ([christophermaier](https://github.com/christophermaier))
- correct the 'ACR' typo in the kubernetes flow diagram [\#5047](https://github.com/habitat-sh/habitat/pull/5047) ([apriofrost](https://github.com/apriofrost))
- Udpate the home-page video [\#5043](https://github.com/habitat-sh/habitat/pull/5043) ([cnunciato](https://github.com/cnunciato))
- Blog Post: Deploying Chef Habitat packages to AKS/ACR [\#5037](https://github.com/habitat-sh/habitat/pull/5037) ([jamesc](https://github.com/jamesc))
- Add Splunk blog post [\#5035](https://github.com/habitat-sh/habitat/pull/5035) ([cnunciato](https://github.com/cnunciato))
- Add the ability to check an upstream depot for packages [\#5034](https://github.com/habitat-sh/habitat/pull/5034) ([raskchanky](https://github.com/raskchanky))
- Add JSON structured logging to the Supervisor [\#5033](https://github.com/habitat-sh/habitat/pull/5033) ([christophermaier](https://github.com/christophermaier))
- Minor copy and formatting edits to AKS docs submission [\#5029](https://github.com/habitat-sh/habitat/pull/5029) ([cnunciato](https://github.com/cnunciato))
- Added docs for Azure Best Practices [\#5027](https://github.com/habitat-sh/habitat/pull/5027) ([jamesc](https://github.com/jamesc))
- compression love for pkg-export-tar [\#5026](https://github.com/habitat-sh/habitat/pull/5026) ([jeremymv2](https://github.com/jeremymv2))
- Allow services to start in the absence of their binds [\#5024](https://github.com/habitat-sh/habitat/pull/5024) ([christophermaier](https://github.com/christophermaier))
- Fix Blog Post Title [\#5018](https://github.com/habitat-sh/habitat/pull/5018) ([cnunciato](https://github.com/cnunciato))
- Create new blog on hab and k8s [\#5017](https://github.com/habitat-sh/habitat/pull/5017) ([tashimi](https://github.com/tashimi))
- Create k8s updater blog [\#5016](https://github.com/habitat-sh/habitat/pull/5016) ([tashimi](https://github.com/tashimi))
- Create Hab and Open Service Broker blog [\#5015](https://github.com/habitat-sh/habitat/pull/5015) ([tashimi](https://github.com/tashimi))
- Fix README diagram and demo links [\#5014](https://github.com/habitat-sh/habitat/pull/5014) ([apriofrost](https://github.com/apriofrost))
- Fix origin key upload command args [\#5013](https://github.com/habitat-sh/habitat/pull/5013) ([chefsalim](https://github.com/chefsalim))
- Update CODEOWNERS [\#5008](https://github.com/habitat-sh/habitat/pull/5008) ([chefsalim](https://github.com/chefsalim))
- Update bldr.toml doc to update and consolidate information [\#5007](https://github.com/habitat-sh/habitat/pull/5007) ([chefsalim](https://github.com/chefsalim))
- bumping up the nav breakpoint so github doesnt wrap [\#5006](https://github.com/habitat-sh/habitat/pull/5006) ([mgamini](https://github.com/mgamini))
- Temporarily remove baumanj [\#5005](https://github.com/habitat-sh/habitat/pull/5005) ([baumanj](https://github.com/baumanj))
- fixed hab bldr job status [\#5003](https://github.com/habitat-sh/habitat/pull/5003) ([elliott-davis](https://github.com/elliott-davis))
- find/replace to remove command aliases [\#4998](https://github.com/habitat-sh/habitat/pull/4998) ([brewn](https://github.com/brewn))
- Updating logos in blog posts [\#4993](https://github.com/habitat-sh/habitat/pull/4993) ([mgamini](https://github.com/mgamini))
- Add LD\_LIBRARY\_PATH hack for Supervisor package [\#4987](https://github.com/habitat-sh/habitat/pull/4987) ([christophermaier](https://github.com/christophermaier))
- Use a Builder Personal Access Token for TravisCI [\#4984](https://github.com/habitat-sh/habitat/pull/4984) ([christophermaier](https://github.com/christophermaier))
- Bump Nokogiri [\#4983](https://github.com/habitat-sh/habitat/pull/4983) ([cnunciato](https://github.com/cnunciato))
- Add note to bastion ring about container schedulers [\#4982](https://github.com/habitat-sh/habitat/pull/4982) ([tashimi](https://github.com/tashimi))
- Emit the correct target when failing to upload dependency [\#4978](https://github.com/habitat-sh/habitat/pull/4978) ([raskchanky](https://github.com/raskchanky))
- This may not be for you; it is for applications [\#4973](https://github.com/habitat-sh/habitat/pull/4973) ([nathenharvey](https://github.com/nathenharvey))
- Expand the docs around pattern matches in the .bldr.toml files [\#4971](https://github.com/habitat-sh/habitat/pull/4971) ([raskchanky](https://github.com/raskchanky))
- Correct a typo in the leader-election docs [\#4966](https://github.com/habitat-sh/habitat/pull/4966) ([cnunciato](https://github.com/cnunciato))
- Move EventSrv-Protocol crate back into main repository [\#4963](https://github.com/habitat-sh/habitat/pull/4963) ([reset](https://github.com/reset))
- update screenshots containing logos, remove unused screenshots [\#4957](https://github.com/habitat-sh/habitat/pull/4957) ([apriofrost](https://github.com/apriofrost))
- Add secrets link to the docs sidebar [\#4955](https://github.com/habitat-sh/habitat/pull/4955) ([cnunciato](https://github.com/cnunciato))
- Add `hab sup secret` subcommand [\#4953](https://github.com/habitat-sh/habitat/pull/4953) ([reset](https://github.com/reset))
- Fix automatic secret generation on Supervisor start [\#4952](https://github.com/habitat-sh/habitat/pull/4952) ([reset](https://github.com/reset))
- Add docs for origin secrets [\#4951](https://github.com/habitat-sh/habitat/pull/4951) ([cnunciato](https://github.com/cnunciato))
- fix on-prem Builder depot diagram link [\#4949](https://github.com/habitat-sh/habitat/pull/4949) ([apriofrost](https://github.com/apriofrost))
- update every picture containing logos under source/images/demo [\#4944](https://github.com/habitat-sh/habitat/pull/4944) ([apriofrost](https://github.com/apriofrost))
- Document launcher build and release process [\#4942](https://github.com/habitat-sh/habitat/pull/4942) ([baumanj](https://github.com/baumanj))
- Fix link for local builder setup instructions [\#4938](https://github.com/habitat-sh/habitat/pull/4938) ([baumanj](https://github.com/baumanj))
- Bump to rustfmt preview 0.3.8 [\#4936](https://github.com/habitat-sh/habitat/pull/4936) ([reset](https://github.com/reset))
- add on-prem Builder depot flow diagram [\#4935](https://github.com/habitat-sh/habitat/pull/4935) ([apriofrost](https://github.com/apriofrost))
- More logo cleanup [\#4928](https://github.com/habitat-sh/habitat/pull/4928) ([cnunciato](https://github.com/cnunciato))
- Logos: Removing logo from Packaging demo [\#4921](https://github.com/habitat-sh/habitat/pull/4921) ([mgamini](https://github.com/mgamini))
- 4906: new footer! [\#4912](https://github.com/habitat-sh/habitat/pull/4912) ([mgamini](https://github.com/mgamini))
- update k8s three tiers of service deployment diagram [\#4907](https://github.com/habitat-sh/habitat/pull/4907) ([apriofrost](https://github.com/apriofrost))
- Update the favicon [\#4901](https://github.com/habitat-sh/habitat/pull/4901) ([cnunciato](https://github.com/cnunciato))
- Fix typo in `hab export docker --help` [\#4899](https://github.com/habitat-sh/habitat/pull/4899) ([baumanj](https://github.com/baumanj))
- remove logo marks in diagrams, update Chef Habitat flow diagram [\#4896](https://github.com/habitat-sh/habitat/pull/4896) ([apriofrost](https://github.com/apriofrost))
- Add a note about updating the CLI docs [\#4894](https://github.com/habitat-sh/habitat/pull/4894) ([cnunciato](https://github.com/cnunciato))
- 4881: adding id [\#4893](https://github.com/habitat-sh/habitat/pull/4893) ([mgamini](https://github.com/mgamini))
- move FS\_ROOT usage inside test to avoid warn [\#4891](https://github.com/habitat-sh/habitat/pull/4891) ([mwrock](https://github.com/mwrock))
- Add Testing Exporters section [\#4890](https://github.com/habitat-sh/habitat/pull/4890) ([baumanj](https://github.com/baumanj))
- Fix a mistake in user.toml usage documentation [\#4887](https://github.com/habitat-sh/habitat/pull/4887) ([krnowak](https://github.com/krnowak))
- Add some missing env\_logger initialization calls and remove unused deps [\#4885](https://github.com/habitat-sh/habitat/pull/4885) ([baumanj](https://github.com/baumanj))
- update readme diagram link [\#4880](https://github.com/habitat-sh/habitat/pull/4880) ([apriofrost](https://github.com/apriofrost))
- document the use of a user.toml [\#4876](https://github.com/habitat-sh/habitat/pull/4876) ([mwrock](https://github.com/mwrock))
- Generate template reference docs \(and update them\) [\#4874](https://github.com/habitat-sh/habitat/pull/4874) ([cnunciato](https://github.com/cnunciato))
- Suppress related videos on the home page demo [\#4869](https://github.com/habitat-sh/habitat/pull/4869) ([cnunciato](https://github.com/cnunciato))
- Add a bit more context to use of SSL\_CERT\_FILE variable [\#4866](https://github.com/habitat-sh/habitat/pull/4866) ([christophermaier](https://github.com/christophermaier))
- update Chef Habitat logo files to remove diamond logo marks [\#4865](https://github.com/habitat-sh/habitat/pull/4865) ([apriofrost](https://github.com/apriofrost))
- Update docs side nav, reference and diagram page [\#4856](https://github.com/habitat-sh/habitat/pull/4856) ([apriofrost](https://github.com/apriofrost))
- Fix hab pkg export cf [\#4854](https://github.com/habitat-sh/habitat/pull/4854) ([baumanj](https://github.com/baumanj))
- Update docs home page design [\#4853](https://github.com/habitat-sh/habitat/pull/4853) ([apriofrost](https://github.com/apriofrost))
- Revert to boolean-based health in CensusMember [\#4844](https://github.com/habitat-sh/habitat/pull/4844) ([christophermaier](https://github.com/christophermaier))
- Update hab bldr job status [\#4841](https://github.com/habitat-sh/habitat/pull/4841) ([chefsalim](https://github.com/chefsalim))
- Expose bind leader directly [\#4836](https://github.com/habitat-sh/habitat/pull/4836) ([christophermaier](https://github.com/christophermaier))
- Remove Heap script [\#4835](https://github.com/habitat-sh/habitat/pull/4835) ([cnunciato](https://github.com/cnunciato))
- Update HAB\_STUDIO\_BINARY testing changes section [\#4826](https://github.com/habitat-sh/habitat/pull/4826) ([baumanj](https://github.com/baumanj))
- Add comments to indicate how to test local changes to these files [\#4825](https://github.com/habitat-sh/habitat/pull/4825) ([baumanj](https://github.com/baumanj))
- Formalize template rendering context [\#4823](https://github.com/habitat-sh/habitat/pull/4823) ([christophermaier](https://github.com/christophermaier))
- Docs+blog post update [\#4820](https://github.com/habitat-sh/habitat/pull/4820) ([zeenix](https://github.com/zeenix))
- Update README.md to include getting-started materials for new users [\#4817](https://github.com/habitat-sh/habitat/pull/4817) ([apriofrost](https://github.com/apriofrost))
- adding hab pkg info subcommand [\#4814](https://github.com/habitat-sh/habitat/pull/4814) ([jeremymv2](https://github.com/jeremymv2))
- Make `sed -i` work on both linux and Mac OS [\#4813](https://github.com/habitat-sh/habitat/pull/4813) ([baumanj](https://github.com/baumanj))
- Remove bldr encrypt command [\#4811](https://github.com/habitat-sh/habitat/pull/4811) ([chefsalim](https://github.com/chefsalim))
- One small step for release..one large leap for acceptance [\#4801](https://github.com/habitat-sh/habitat/pull/4801) ([chefsalim](https://github.com/chefsalim))
- Update release doc to add hab-backline update [\#4800](https://github.com/habitat-sh/habitat/pull/4800) ([chefsalim](https://github.com/chefsalim))
- always use stable windows-service and fail build on failure [\#4797](https://github.com/habitat-sh/habitat/pull/4797) ([mwrock](https://github.com/mwrock))
- add note to release doc about cleaning a full mac disk [\#4796](https://github.com/habitat-sh/habitat/pull/4796) ([mwrock](https://github.com/mwrock))
- bumping dev version [\#4795](https://github.com/habitat-sh/habitat/pull/4795) ([mwrock](https://github.com/mwrock))
- Update the CLI docs for 0.55.0 [\#4794](https://github.com/habitat-sh/habitat/pull/4794) ([cnunciato](https://github.com/cnunciato))
- Elliott/release blog [\#4791](https://github.com/habitat-sh/habitat/pull/4791) ([elliott-davis](https://github.com/elliott-davis))
- Fix checks to skip travis test runs when there are no relevant changes [\#4789](https://github.com/habitat-sh/habitat/pull/4789) ([baumanj](https://github.com/baumanj))
- pkg-export-k8s: Use versioned tag when '-d' is passed [\#4788](https://github.com/habitat-sh/habitat/pull/4788) ([zeenix](https://github.com/zeenix))
- add note about exporting w/o builder [\#4784](https://github.com/habitat-sh/habitat/pull/4784) ([brewn](https://github.com/brewn))
- document docker requirement for linux [\#4782](https://github.com/habitat-sh/habitat/pull/4782) ([brewn](https://github.com/brewn))
- pkg-export-k8s: Add status reporting [\#4781](https://github.com/habitat-sh/habitat/pull/4781) ([zeenix](https://github.com/zeenix))
